<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>Loopback</name>
    <message>
        <location filename="loopback.cpp" line="133"/>
        <source>This plugin provides DMX loopback. Data written to each output is forwarded to the respective input.</source>
        <translation>Aquest plugin proveeix un bucle DMX. Les dades de cada Sortida són reenviats a la seva respectiva entrada.</translation>
    </message>
    <message>
        <location filename="loopback.cpp" line="146"/>
        <source>Output</source>
        <translation>Sortida</translation>
    </message>
    <message>
        <location filename="loopback.cpp" line="149"/>
        <location filename="loopback.cpp" line="171"/>
        <source>Status: Used</source>
        <translation>Estat: Usat</translation>
    </message>
    <message>
        <location filename="loopback.cpp" line="152"/>
        <location filename="loopback.cpp" line="174"/>
        <source>Status: Not used</source>
        <translation>Estat: No usat</translation>
    </message>
    <message>
        <location filename="loopback.cpp" line="168"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
</context>
</TS>
